[webkit-changes] [88611] trunk/Source/WebCore

2011-06-12 Thread msaboff
Title: [88611] trunk/Source/WebCore








Revision 88611
Author msab...@apple.com
Date 2011-06-11 23:01:25 -0700 (Sat, 11 Jun 2011)


Log Message
2011-06-11  Michael Saboff  msab...@apple.com

Reviewed by James Robinson.

REGRESSION(88260): 10-50% performance regression across many page cyclers
https://bugs.webkit.org/show_bug.cgi?id=62349

Made CHROMIUM platform specific values for cMaxInactiveFontData and
cTargetInactiveFontData to mitigate the current performance issue on Chromium
page cycler tests.  Made the chromium value for cMaxInactiveFontData 250 based
on recommendation from James Robinson.  Changed cTargetInactiveFontData to 200
so that 50 inactive fonts will be cleaned up at a time.

Change made to address existing Chromium performance test regression.

* platform/graphics/FontCache.cpp:

Modified Paths

trunk/Source/WebCore/ChangeLog
trunk/Source/WebCore/platform/graphics/FontCache.cpp




Diff

Modified: trunk/Source/WebCore/ChangeLog (88610 => 88611)

--- trunk/Source/WebCore/ChangeLog	2011-06-12 04:19:39 UTC (rev 88610)
+++ trunk/Source/WebCore/ChangeLog	2011-06-12 06:01:25 UTC (rev 88611)
@@ -1,3 +1,20 @@
+2011-06-11  Michael Saboff  msab...@apple.com
+
+Reviewed by James Robinson.
+
+REGRESSION(88260): 10-50% performance regression across many page cyclers
+https://bugs.webkit.org/show_bug.cgi?id=62349
+
+Made CHROMIUM platform specific values for cMaxInactiveFontData and
+cTargetInactiveFontData to mitigate the current performance issue on Chromium
+page cycler tests.  Made the chromium value for cMaxInactiveFontData 250 based
+on recommendation from James Robinson.  Changed cTargetInactiveFontData to 200
+so that 50 inactive fonts will be cleaned up at a time.
+
+Change made to address existing Chromium performance test regression.
+
+* platform/graphics/FontCache.cpp:
+
 2011-06-11  Adam Barth  aba...@webkit.org
 
 Reviewed by Darin Adler.


Modified: trunk/Source/WebCore/platform/graphics/FontCache.cpp (88610 => 88611)

--- trunk/Source/WebCore/platform/graphics/FontCache.cpp	2011-06-12 04:19:39 UTC (rev 88610)
+++ trunk/Source/WebCore/platform/graphics/FontCache.cpp	2011-06-12 06:01:25 UTC (rev 88611)
@@ -251,8 +251,13 @@
 
 static FontDataCache* gFontDataCache = 0;
 
-const int cMaxInactiveFontData = 120; // Pretty Low Threshold
-const int cTargetInactiveFontData = 100;
+#if PLATFORM(CHROMIUM)
+const int cMaxInactiveFontData = 250;
+const int cTargetInactiveFontData = 200;
+#else
+const int cMaxInactiveFontData = 50; // Pretty Low Threshold
+const int cTargetInactiveFontData = 30;
+#endif
 static ListHashSetconst SimpleFontData** gInactiveFontData = 0;
 
 SimpleFontData* FontCache::getCachedFontData(const FontDescription fontDescription, const AtomicString family, bool checkingAlternateName, ShouldRetain shouldRetain)






___
webkit-changes mailing list
webkit-changes@lists.webkit.org
http://lists.webkit.org/mailman/listinfo.cgi/webkit-changes


[webkit-changes] [88613] trunk/Source/WebCore

2011-06-12 Thread zimmermann
Title: [88613] trunk/Source/WebCore








Revision 88613
Author zimmerm...@webkit.org
Date 2011-06-12 05:40:40 -0700 (Sun, 12 Jun 2011)


Log Message
2011-06-11  Nikolas Zimmermann  nzimmerm...@rim.com

Reviewed by Dirk Schulze.

Add TextRun charactersLength member
https://bugs.webkit.org/show_bug.cgi?id=62501

Preparation patch 2: Propagate the maximum length of the characters buffer the TextRun operates on, even when we're only measuring a substring.
For example: In RenderText when we're measuring 'len' characters starting from text()-characters() + start, there's a portion
of textLength() - start characters that we're not processing. In order to support ligatures when integrating SVG Fonts
within the GlyphPage concept, we need this extra information, to lookup ligatures even when single chars are measured.
If a font defines an eg ffl ligature, and we're measuring the f of ffl, it shall looukp the ffl glyph from the font,
and skip the next two characters (this will be done in WidthIterator).

This doesn't yet affect any test, the new SVG Fonts code is not merged yet, this is the preparaion patch 2.

* platform/graphics/Font.h: Add yet-unused const TextRun parameter to drawGlyphBuffer/drawEmphasisMarks.
* platform/graphics/FontFastPath.cpp: Ditto. This parameter will be used to looukp the TextRunRenderingContext in a follow-up patch.
(WebCore::Font::drawSimpleText):
(WebCore::Font::drawEmphasisMarksForSimpleText):
(WebCore::Font::drawGlyphBuffer):
(WebCore::Font::drawEmphasisMarks):
* platform/graphics/TextRun.h: Add int m_charactersLength, similar to int m_len. It denotes the maximum length of the characters buffer
   that we're holding. It defaults to the passed len value, but is overriden by explicit setCharactersLength calls.
(WebCore::TextRun::TextRun):
(WebCore::TextRun::charactersLength):
(WebCore::TextRun::setCharactersLength):
* platform/graphics/mac/FontComplexTextMac.cpp: Pass TextRun do drawGlyphBuffer/drawEmphasisMarks.
(WebCore::Font::drawComplexText):
(WebCore::Font::drawEmphasisMarksForComplexText):
* platform/graphics/win/FontWin.cpp: Ditto.
(WebCore::Font::drawComplexText):
(WebCore::Font::drawEmphasisMarksForComplexText):
* platform/graphics/wx/FontWx.cpp: Ditto.
(WebCore::Font::drawComplexText):
(WebCore::Font::drawEmphasisMarksForComplexText):
* rendering/InlineTextBox.cpp: Call setCharactersLength on the processed TextRun.
(WebCore::InlineTextBox::constructTextRun):
* rendering/RenderBlockLineLayout.cpp: Ditto.
(WebCore::textWidth):
(WebCore::tryHyphenating):
* rendering/RenderText.cpp: Ditto.
(WebCore::RenderText::widthFromCache):
(WebCore::RenderText::computePreferredLogicalWidths):
(WebCore::RenderText::width):
* rendering/svg/SVGInlineTextBox.cpp: Ditto.
(WebCore::SVGInlineTextBox::constructTextRun):

Modified Paths

trunk/Source/WebCore/ChangeLog
trunk/Source/WebCore/platform/graphics/Font.h
trunk/Source/WebCore/platform/graphics/FontFastPath.cpp
trunk/Source/WebCore/platform/graphics/TextRun.h
trunk/Source/WebCore/platform/graphics/mac/FontComplexTextMac.cpp
trunk/Source/WebCore/platform/graphics/win/FontWin.cpp
trunk/Source/WebCore/platform/graphics/wx/FontWx.cpp
trunk/Source/WebCore/rendering/InlineTextBox.cpp
trunk/Source/WebCore/rendering/RenderBlockLineLayout.cpp
trunk/Source/WebCore/rendering/RenderText.cpp
trunk/Source/WebCore/rendering/svg/SVGInlineTextBox.cpp




Diff

Modified: trunk/Source/WebCore/ChangeLog (88612 => 88613)

--- trunk/Source/WebCore/ChangeLog	2011-06-12 11:51:45 UTC (rev 88612)
+++ trunk/Source/WebCore/ChangeLog	2011-06-12 12:40:40 UTC (rev 88613)
@@ -1,3 +1,51 @@
+2011-06-11  Nikolas Zimmermann  nzimmerm...@rim.com
+
+Reviewed by Dirk Schulze.
+
+Add TextRun charactersLength member
+https://bugs.webkit.org/show_bug.cgi?id=62501
+
+Preparation patch 2: Propagate the maximum length of the characters buffer the TextRun operates on, even when we're only measuring a substring.
+For example: In RenderText when we're measuring 'len' characters starting from text()-characters() + start, there's a portion
+of textLength() - start characters that we're not processing. In order to support ligatures when integrating SVG Fonts
+within the GlyphPage concept, we need this extra information, to lookup ligatures even when single chars are measured.
+If a font defines an eg ffl ligature, and we're measuring the f of ffl, it shall looukp the ffl glyph from the font,
+and skip the next two characters (this will be done in WidthIterator).
+
+This doesn't yet affect any test, the new SVG Fonts code is not merged yet, this is the preparaion 

[webkit-changes] [88615] trunk/Source/WebCore

2011-06-12 Thread abarth
Title: [88615] trunk/Source/WebCore








Revision 88615
Author aba...@webkit.org
Date 2011-06-12 09:57:54 -0700 (Sun, 12 Jun 2011)


Log Message
2011-06-12  Adam Barth  aba...@webkit.org

Reviewed by Andreas Kling.

Minor user-gesture related cleanup
https://bugs.webkit.org/show_bug.cgi?id=62511

In reading the user gesture code, I noticed that these lines of code
should be deleted because they don't do anything.

* bindings/v8/NPV8Object.cpp:
* html/HTMLAnchorElement.cpp:
* html/HTMLVideoElement.idl:

Modified Paths

trunk/Source/WebCore/ChangeLog
trunk/Source/WebCore/bindings/v8/NPV8Object.cpp
trunk/Source/WebCore/html/HTMLAnchorElement.cpp
trunk/Source/WebCore/html/HTMLVideoElement.idl




Diff

Modified: trunk/Source/WebCore/ChangeLog (88614 => 88615)

--- trunk/Source/WebCore/ChangeLog	2011-06-12 14:52:55 UTC (rev 88614)
+++ trunk/Source/WebCore/ChangeLog	2011-06-12 16:57:54 UTC (rev 88615)
@@ -1,3 +1,17 @@
+2011-06-12  Adam Barth  aba...@webkit.org
+
+Reviewed by Andreas Kling.
+
+Minor user-gesture related cleanup
+https://bugs.webkit.org/show_bug.cgi?id=62511
+
+In reading the user gesture code, I noticed that these lines of code
+should be deleted because they don't do anything.
+
+* bindings/v8/NPV8Object.cpp:
+* html/HTMLAnchorElement.cpp:
+* html/HTMLVideoElement.idl:
+
 2011-06-11  Nikolas Zimmermann  nzimmerm...@rim.com
 
 Reviewed by Dirk Schulze.


Modified: trunk/Source/WebCore/bindings/v8/NPV8Object.cpp (88614 => 88615)

--- trunk/Source/WebCore/bindings/v8/NPV8Object.cpp	2011-06-12 14:52:55 UTC (rev 88614)
+++ trunk/Source/WebCore/bindings/v8/NPV8Object.cpp	2011-06-12 16:57:54 UTC (rev 88615)
@@ -34,7 +34,6 @@
 #include OwnArrayPtr.h
 #include PlatformString.h
 #include ScriptSourceCode.h
-#include UserGestureIndicator.h
 #include V8GCController.h
 #include V8Helpers.h
 #include V8NPUtils.h


Modified: trunk/Source/WebCore/html/HTMLAnchorElement.cpp (88614 => 88615)

--- trunk/Source/WebCore/html/HTMLAnchorElement.cpp	2011-06-12 14:52:55 UTC (rev 88614)
+++ trunk/Source/WebCore/html/HTMLAnchorElement.cpp	2011-06-12 16:57:54 UTC (rev 88615)
@@ -39,7 +39,6 @@
 #include ResourceHandle.h
 #include SecurityOrigin.h
 #include Settings.h
-#include UserGestureIndicator.h
 
 namespace WebCore {
 


Modified: trunk/Source/WebCore/html/HTMLVideoElement.idl (88614 => 88615)

--- trunk/Source/WebCore/html/HTMLVideoElement.idl	2011-06-12 14:52:55 UTC (rev 88614)
+++ trunk/Source/WebCore/html/HTMLVideoElement.idl	2011-06-12 16:57:54 UTC (rev 88615)
@@ -39,9 +39,6 @@
 
 [NeedsUserGestureCheck] void webkitEnterFullscreen() raises (DOMException);
 void webkitExitFullscreen();
-
-[NeedsUserGestureCheck] void webkitEnterFullScreen() raises (DOMException);
-void webkitExitFullScreen();
 
 #if defined(ENABLE_MEDIA_STATISTICS)  ENABLE_MEDIA_STATISTICS
 // The number of frames that have been decoded and made available for






___
webkit-changes mailing list
webkit-changes@lists.webkit.org
http://lists.webkit.org/mailman/listinfo.cgi/webkit-changes


[webkit-changes] [88616] trunk

2011-06-12 Thread mahesh . kulkarni
Title: [88616] trunk








Revision 88616
Author mahesh.kulka...@nokia.com
Date 2011-06-12 10:23:28 -0700 (Sun, 12 Jun 2011)


Log Message
[Qt] LayoutTestController needs setTextDirection implementation
https://bugs.webkit.org/show_bug.cgi?id=62442

Reviewed by Antonio Gomes.

Tools: 

Implements LayoutController.setTextDirection.

* DumpRenderTree/qt/LayoutTestControllerQt.cpp:
(LayoutTestController::setTextDirection):
* DumpRenderTree/qt/LayoutTestControllerQt.h:

LayoutTests: 

Unskipping fast/html/set-text-direction.html. 

* platform/qt/Skipped:

Modified Paths

trunk/LayoutTests/ChangeLog
trunk/LayoutTests/platform/qt/Skipped
trunk/Tools/ChangeLog
trunk/Tools/DumpRenderTree/qt/LayoutTestControllerQt.cpp
trunk/Tools/DumpRenderTree/qt/LayoutTestControllerQt.h




Diff

Modified: trunk/LayoutTests/ChangeLog (88615 => 88616)

--- trunk/LayoutTests/ChangeLog	2011-06-12 16:57:54 UTC (rev 88615)
+++ trunk/LayoutTests/ChangeLog	2011-06-12 17:23:28 UTC (rev 88616)
@@ -1,3 +1,14 @@
+2011-06-12  Mahesh Kulkarni  mahesh.kulka...@nokia.com
+
+Reviewed by Antonio Gomes.
+
+[Qt] LayoutTestController needs setTextDirection implementation
+https://bugs.webkit.org/show_bug.cgi?id=62442
+
+Unskipping fast/html/set-text-direction.html. 
+
+* platform/qt/Skipped:
+
 2011-06-12  Robert Hogan  rob...@webkit.org
 
 Reviewed by Andreas Kling.


Modified: trunk/LayoutTests/platform/qt/Skipped (88615 => 88616)

--- trunk/LayoutTests/platform/qt/Skipped	2011-06-12 16:57:54 UTC (rev 88615)
+++ trunk/LayoutTests/platform/qt/Skipped	2011-06-12 17:23:28 UTC (rev 88616)
@@ -653,7 +653,7 @@
 loader/go-back-to-different-window-size.html
 
 # Missing layoutTestController.findString() http://webkit.org/b/50236
-editing/text-iterator/findString.html
+#editing/text-iterator/findString.html
 
 # Missing layoutTestController.setAlwaysAcceptCookies()
 http/tests/xmlhttprequest/access-control-basic-allow-preflight-cache-timeout.html
@@ -2505,9 +2505,6 @@
 fast/events/selectstart-by-double-triple-clicks.html
 fast/events/selectstart-by-drag.html
 
-# LayoutTestController::setTextDirection is not implemented.
-fast/html/set-text-direction.html
-
 # JSC does not support setIsolatedWorldSecurityOrigin (http://webkit.org/b/61540)
 http/tests/security/isolatedWorld/cross-origin-xhr.html
 


Modified: trunk/Tools/ChangeLog (88615 => 88616)

--- trunk/Tools/ChangeLog	2011-06-12 16:57:54 UTC (rev 88615)
+++ trunk/Tools/ChangeLog	2011-06-12 17:23:28 UTC (rev 88616)
@@ -1,3 +1,16 @@
+2011-06-12  Mahesh Kulkarni  mahesh.kulka...@nokia.com
+
+Reviewed by Antonio Gomes.
+
+[Qt] LayoutTestController needs setTextDirection implementation
+https://bugs.webkit.org/show_bug.cgi?id=62442
+
+Implements LayoutController.setTextDirection.
+
+* DumpRenderTree/qt/LayoutTestControllerQt.cpp:
+(LayoutTestController::setTextDirection):
+* DumpRenderTree/qt/LayoutTestControllerQt.h:
+
 2011-06-10  Ryosuke Niwa  rn...@webkit.org
 
 Reviewed by Ojan Vafai.


Modified: trunk/Tools/DumpRenderTree/qt/LayoutTestControllerQt.cpp (88615 => 88616)

--- trunk/Tools/DumpRenderTree/qt/LayoutTestControllerQt.cpp	2011-06-12 16:57:54 UTC (rev 88615)
+++ trunk/Tools/DumpRenderTree/qt/LayoutTestControllerQt.cpp	2011-06-12 17:23:28 UTC (rev 88616)
@@ -954,5 +954,15 @@
 return DumpRenderTreeSupportQt::layerTreeAsText(m_drt-webPage()-mainFrame());
 }
 
+void LayoutTestController::setTextDirection(const QString directionName)
+{
+if (directionName == auto)
+m_drt-webPage()-triggerAction(QWebPage::SetTextDirectionDefault);
+else if (directionName == rtl)
+m_drt-webPage()-triggerAction(QWebPage::SetTextDirectionRightToLeft);
+else if (directionName == ltr)
+m_drt-webPage()-triggerAction(QWebPage::SetTextDirectionLeftToRight);
+}
+
 const unsigned LayoutTestController::maxViewWidth = 800;
 const unsigned LayoutTestController::maxViewHeight = 600;


Modified: trunk/Tools/DumpRenderTree/qt/LayoutTestControllerQt.h (88615 => 88616)

--- trunk/Tools/DumpRenderTree/qt/LayoutTestControllerQt.h	2011-06-12 16:57:54 UTC (rev 88615)
+++ trunk/Tools/DumpRenderTree/qt/LayoutTestControllerQt.h	2011-06-12 17:23:28 UTC (rev 88616)
@@ -274,6 +274,7 @@
 void observeStorageTrackerNotifications(unsigned number);
 void syncLocalStorage();
 QString layerTreeAsText();
+void setTextDirection(const QString directionName);
 
 private slots:
 void processWork();






___
webkit-changes mailing list
webkit-changes@lists.webkit.org
http://lists.webkit.org/mailman/listinfo.cgi/webkit-changes


[webkit-changes] [88617] trunk/Source/WebCore

2011-06-12 Thread mitz
Title: [88617] trunk/Source/WebCore








Revision 88617
Author m...@apple.com
Date 2011-06-12 11:27:00 -0700 (Sun, 12 Jun 2011)


Log Message
rdar://problem/9513180 REGRESSION (r84166): recalcStyle for display:inline to display:none transition has complexity N^2 where N is the number of child Text nodes
https://bugs.webkit.org/show_bug.cgi?id=61557

Reviewed by Darin Adler.

Replaced the fix for bug 58500 with a refined version.

* rendering/RenderText.cpp:
(WebCore::RenderText::clippedOverflowRectForRepaint): Use the containing block unless it is
across a layer boundary.

Modified Paths

trunk/Source/WebCore/ChangeLog
trunk/Source/WebCore/rendering/RenderText.cpp




Diff

Modified: trunk/Source/WebCore/ChangeLog (88616 => 88617)

--- trunk/Source/WebCore/ChangeLog	2011-06-12 17:23:28 UTC (rev 88616)
+++ trunk/Source/WebCore/ChangeLog	2011-06-12 18:27:00 UTC (rev 88617)
@@ -1,3 +1,16 @@
+2011-06-12  Dan Bernstein  m...@apple.com
+
+Reviewed by Darin Adler.
+
+rdar://problem/9513180 REGRESSION (r84166): recalcStyle for display:inline to display:none transition has complexity N^2 where N is the number of child Text nodes
+https://bugs.webkit.org/show_bug.cgi?id=61557
+
+Replaced the fix for bug 58500 with a refined version.
+
+* rendering/RenderText.cpp:
+(WebCore::RenderText::clippedOverflowRectForRepaint): Use the containing block unless it is
+across a layer boundary.
+
 2011-06-12  Adam Barth  aba...@webkit.org
 
 Reviewed by Andreas Kling.


Modified: trunk/Source/WebCore/rendering/RenderText.cpp (88616 => 88617)

--- trunk/Source/WebCore/ChangeLog	2011-06-12 18:27:00 UTC (rev 88617)
+++ trunk/Source/WebCore/ChangeLog	2011-06-12 19:21:49 UTC (rev 88618)
@@ -1,3 +1,49 @@
+2011-06-12  Adam Barth  

[webkit-changes] [88619] trunk/Source/WebCore

2011-06-12 Thread abarth
Title: [88619] trunk/Source/WebCore








Revision 88619
Author aba...@webkit.org
Date 2011-06-12 13:01:41 -0700 (Sun, 12 Jun 2011)


Log Message
2011-06-12  Adam Barth  aba...@webkit.org

Fix fullscreen/full-screen-iframe-legacy.html.

* html/HTMLVideoElement.idl:

Modified Paths

trunk/Source/WebCore/ChangeLog
trunk/Source/WebCore/html/HTMLVideoElement.idl




Diff

Modified: trunk/Source/WebCore/ChangeLog (88618 => 88619)

--- trunk/Source/WebCore/ChangeLog	2011-06-12 19:21:49 UTC (rev 88618)
+++ trunk/Source/WebCore/ChangeLog	2011-06-12 20:01:41 UTC (rev 88619)
@@ -1,5 +1,11 @@
 2011-06-12  Adam Barth  aba...@webkit.org
 
+Fix fullscreen/full-screen-iframe-legacy.html.
+
+* html/HTMLVideoElement.idl:
+
+2011-06-12  Adam Barth  aba...@webkit.org
+
 Reviewed by Alexey Proskuryakov.
 
 Remove trival forward-to-client member functions from FrameLoader


Modified: trunk/Source/WebCore/html/HTMLVideoElement.idl (88618 => 88619)

--- trunk/Source/WebCore/html/HTMLVideoElement.idl	2011-06-12 19:21:49 UTC (rev 88618)
+++ trunk/Source/WebCore/html/HTMLVideoElement.idl	2011-06-12 20:01:41 UTC (rev 88619)
@@ -40,6 +40,10 @@
 [NeedsUserGestureCheck] void webkitEnterFullscreen() raises (DOMException);
 void webkitExitFullscreen();
 
+// Note the different capitalization of the S in FullScreen.
+[NeedsUserGestureCheck] void webkitEnterFullScreen() raises (DOMException);
+void webkitExitFullScreen();
+
 #if defined(ENABLE_MEDIA_STATISTICS)  ENABLE_MEDIA_STATISTICS
 // The number of frames that have been decoded and made available for
 // playback.






___
webkit-changes mailing list
webkit-changes@lists.webkit.org
http://lists.webkit.org/mailman/listinfo.cgi/webkit-changes


[webkit-changes] [88620] trunk

2011-06-12 Thread commit-queue
Title: [88620] trunk








Revision 88620
Author commit-qu...@webkit.org
Date 2011-06-12 14:24:09 -0700 (Sun, 12 Jun 2011)


Log Message
2011-06-12  Sheriff Bot  webkit.review@gmail.com

Unreviewed, rolling out r88616.
http://trac.webkit.org/changeset/88616
https://bugs.webkit.org/show_bug.cgi?id=62517

It broke editing/text-iterator/findString.html (Requested by
tonikitoo on #webkit).

* platform/qt/Skipped:
2011-06-12  Sheriff Bot  webkit.review@gmail.com

Unreviewed, rolling out r88616.
http://trac.webkit.org/changeset/88616
https://bugs.webkit.org/show_bug.cgi?id=62517

It broke editing/text-iterator/findString.html (Requested by
tonikitoo on #webkit).

* DumpRenderTree/qt/LayoutTestControllerQt.cpp:
* DumpRenderTree/qt/LayoutTestControllerQt.h:

Modified Paths

trunk/LayoutTests/ChangeLog
trunk/LayoutTests/platform/qt/Skipped
trunk/Tools/ChangeLog
trunk/Tools/DumpRenderTree/qt/LayoutTestControllerQt.cpp
trunk/Tools/DumpRenderTree/qt/LayoutTestControllerQt.h




Diff

Modified: trunk/LayoutTests/ChangeLog (88619 => 88620)

--- trunk/LayoutTests/ChangeLog	2011-06-12 20:01:41 UTC (rev 88619)
+++ trunk/LayoutTests/ChangeLog	2011-06-12 21:24:09 UTC (rev 88620)
@@ -1,3 +1,14 @@
+2011-06-12  Sheriff Bot  webkit.review@gmail.com
+
+Unreviewed, rolling out r88616.
+http://trac.webkit.org/changeset/88616
+https://bugs.webkit.org/show_bug.cgi?id=62517
+
+It broke editing/text-iterator/findString.html (Requested by
+tonikitoo on #webkit).
+
+* platform/qt/Skipped:
+
 2011-06-12  Mahesh Kulkarni  mahesh.kulka...@nokia.com
 
 Reviewed by Antonio Gomes.


Modified: trunk/LayoutTests/platform/qt/Skipped (88619 => 88620)

--- trunk/LayoutTests/platform/qt/Skipped	2011-06-12 20:01:41 UTC (rev 88619)
+++ trunk/LayoutTests/platform/qt/Skipped	2011-06-12 21:24:09 UTC (rev 88620)
@@ -653,7 +653,7 @@
 loader/go-back-to-different-window-size.html
 
 # Missing layoutTestController.findString() http://webkit.org/b/50236
-#editing/text-iterator/findString.html
+editing/text-iterator/findString.html
 
 # Missing layoutTestController.setAlwaysAcceptCookies()
 http/tests/xmlhttprequest/access-control-basic-allow-preflight-cache-timeout.html
@@ -2505,6 +2505,9 @@
 fast/events/selectstart-by-double-triple-clicks.html
 fast/events/selectstart-by-drag.html
 
+# LayoutTestController::setTextDirection is not implemented.
+fast/html/set-text-direction.html
+
 # JSC does not support setIsolatedWorldSecurityOrigin (http://webkit.org/b/61540)
 http/tests/security/isolatedWorld/cross-origin-xhr.html
 


Modified: trunk/Tools/ChangeLog (88619 => 88620)

--- trunk/Tools/ChangeLog	2011-06-12 20:01:41 UTC (rev 88619)
+++ trunk/Tools/ChangeLog	2011-06-12 21:24:09 UTC (rev 88620)
@@ -1,3 +1,15 @@
+2011-06-12  Sheriff Bot  webkit.review@gmail.com
+
+Unreviewed, rolling out r88616.
+http://trac.webkit.org/changeset/88616
+https://bugs.webkit.org/show_bug.cgi?id=62517
+
+It broke editing/text-iterator/findString.html (Requested by
+tonikitoo on #webkit).
+
+* DumpRenderTree/qt/LayoutTestControllerQt.cpp:
+* DumpRenderTree/qt/LayoutTestControllerQt.h:
+
 2011-06-12  Mahesh Kulkarni  mahesh.kulka...@nokia.com
 
 Reviewed by Antonio Gomes.


Modified: trunk/Tools/DumpRenderTree/qt/LayoutTestControllerQt.cpp (88619 => 88620)

--- trunk/Tools/DumpRenderTree/qt/LayoutTestControllerQt.cpp	2011-06-12 20:01:41 UTC (rev 88619)
+++ trunk/Tools/DumpRenderTree/qt/LayoutTestControllerQt.cpp	2011-06-12 21:24:09 UTC (rev 88620)
@@ -954,15 +954,5 @@
 return DumpRenderTreeSupportQt::layerTreeAsText(m_drt-webPage()-mainFrame());
 }
 
-void LayoutTestController::setTextDirection(const QString directionName)
-{
-if (directionName == auto)
-m_drt-webPage()-triggerAction(QWebPage::SetTextDirectionDefault);
-else if (directionName == rtl)
-m_drt-webPage()-triggerAction(QWebPage::SetTextDirectionRightToLeft);
-else if (directionName == ltr)
-m_drt-webPage()-triggerAction(QWebPage::SetTextDirectionLeftToRight);
-}
-
 const unsigned LayoutTestController::maxViewWidth = 800;
 const unsigned LayoutTestController::maxViewHeight = 600;


Modified: trunk/Tools/DumpRenderTree/qt/LayoutTestControllerQt.h (88619 => 88620)

--- trunk/Tools/DumpRenderTree/qt/LayoutTestControllerQt.h	2011-06-12 20:01:41 UTC (rev 88619)
+++ trunk/Tools/DumpRenderTree/qt/LayoutTestControllerQt.h	2011-06-12 21:24:09 UTC (rev 88620)
@@ -274,7 +274,6 @@
 void observeStorageTrackerNotifications(unsigned number);
 void syncLocalStorage();
 QString layerTreeAsText();
-void setTextDirection(const QString directionName);
 
 private slots:
 void processWork();






___
webkit-changes mailing list
webkit-changes@lists.webkit.org

[webkit-changes] [88621] trunk/Source/WebKit/gtk

2011-06-12 Thread xan
Title: [88621] trunk/Source/WebKit/gtk








Revision 88621
Author x...@webkit.org
Date 2011-06-12 16:34:10 -0700 (Sun, 12 Jun 2011)


Log Message
2011-06-12  Xan Lopez  xlo...@igalia.com

Reviewed by Martin Robinson.

[GTK] Remove webkit_web_view_get_selected_text
https://bugs.webkit.org/show_bug.cgi?id=62512

It's no longer used and it's a private method, so it can be
removed.

* webkit/webkitwebview.cpp: kill it.
* webkit/webkitwebviewprivate.h: ditto.

Modified Paths

trunk/Source/WebKit/gtk/ChangeLog
trunk/Source/WebKit/gtk/webkit/webkitwebview.cpp
trunk/Source/WebKit/gtk/webkit/webkitwebviewprivate.h




Diff

Modified: trunk/Source/WebKit/gtk/ChangeLog (88620 => 88621)

--- trunk/Source/WebKit/gtk/ChangeLog	2011-06-12 21:24:09 UTC (rev 88620)
+++ trunk/Source/WebKit/gtk/ChangeLog	2011-06-12 23:34:10 UTC (rev 88621)
@@ -1,3 +1,16 @@
+2011-06-12  Xan Lopez  xlo...@igalia.com
+
+Reviewed by Martin Robinson.
+
+[GTK] Remove webkit_web_view_get_selected_text
+https://bugs.webkit.org/show_bug.cgi?id=62512
+
+It's no longer used and it's a private method, so it can be
+removed.
+
+* webkit/webkitwebview.cpp: kill it.
+* webkit/webkitwebviewprivate.h: ditto.
+
 2011-06-12  Adam Barth  aba...@webkit.org
 
 Reviewed by Alexey Proskuryakov.


Modified: trunk/Source/WebKit/gtk/webkit/webkitwebview.cpp (88620 => 88621)

--- trunk/Source/WebKit/gtk/webkit/webkitwebview.cpp	2011-06-12 21:24:09 UTC (rev 88620)
+++ trunk/Source/WebKit/gtk/webkit/webkitwebview.cpp	2011-06-12 23:34:10 UTC (rev 88621)
@@ -4216,22 +4216,6 @@
 }
 
 /**
- * webkit_web_view_get_selected_text:
- * @webView: a #WebKitWebView
- *
- * Retrieves the selected text if any.
- *
- * Return value: a newly allocated string with the selection or %NULL
- */
-gchar* webkit_web_view_get_selected_text(WebKitWebView* webView)
-{
-g_return_val_if_fail(WEBKIT_IS_WEB_VIEW(webView), 0);
-
-Frame* frame = core(webView)-focusController()-focusedOrMainFrame();
-return g_strdup(frame-editor()-selectedText().utf8().data());
-}
-
-/**
  * webkit_web_view_select_all:
  * @webView: a #WebKitWebView
  *


Modified: trunk/Source/WebKit/gtk/webkit/webkitwebviewprivate.h (88620 => 88621)

--- trunk/Source/WebKit/gtk/webkit/webkitwebviewprivate.h	2011-06-12 21:24:09 UTC (rev 88620)
+++ trunk/Source/WebKit/gtk/webkit/webkitwebviewprivate.h	2011-06-12 23:34:10 UTC (rev 88621)
@@ -119,8 +119,6 @@
 void webkit_web_view_set_tooltip_text(WebKitWebView*, const char*);
 GtkMenu* webkit_web_view_get_context_menu(WebKitWebView*);
 
-WEBKIT_API gchar* webkit_web_view_get_selected_text(WebKitWebView*);
-
 void webViewEnterFullscreen(WebKitWebView* webView, WebCore::Node*);
 void webViewExitFullscreen(WebKitWebView* webView);
 






___
webkit-changes mailing list
webkit-changes@lists.webkit.org
http://lists.webkit.org/mailman/listinfo.cgi/webkit-changes


[webkit-changes] [88625] trunk

2011-06-12 Thread dominicc
Title: [88625] trunk








Revision 88625
Author domin...@chromium.org
Date 2011-06-12 20:05:02 -0700 (Sun, 12 Jun 2011)


Log Message
2011-06-12  Dominic Cooney  domin...@chromium.org

Reviewed by Hajime Morita.

Add window.internals to WebKit2's WebKitTestRunner.
https://bugs.webkit.org/show_bug.cgi?id=61073

* platform/mac-wk2/Skipped: unskip fast/harness/internals-object.html
2011-06-12  Dominic Cooney  domin...@chromium.org

Reviewed by Hajime Morita.

Add window.internals to WebKit2's WebKitTestRunner.
https://bugs.webkit.org/show_bug.cgi?id=61073

* WebKit.vcproj/WebKit.sln: InjectedBundle depends on WebCoreTestSupport
2011-06-12  Dominic Cooney  domin...@chromium.org

Reviewed by Hajime Morita.

Add window.internals to WebKit2's WebKitTestRunner.
https://bugs.webkit.org/show_bug.cgi?id=61073

Test: fast/harness/internals-object.html

* WebKitTestRunner/Configurations/InjectedBundleCFLite.vsprops:
* WebKitTestRunner/Configurations/InjectedBundleCommon.vsprops:
* WebKitTestRunner/Configurations/InjectedBundleCoreFoundation.vsprops:
* WebKitTestRunner/InjectedBundle/InjectedBundlePage.cpp:
(WTR::InjectedBundlePage::didClearWindowForFrame): initialize window.internals
* WebKitTestRunner/WebKitTestRunner.xcodeproj/project.pbxproj:

Modified Paths

trunk/LayoutTests/ChangeLog
trunk/LayoutTests/platform/mac-wk2/Skipped
trunk/Source/WebKit/win/ChangeLog
trunk/Source/WebKit/win/WebKit.vcproj/WebKit.sln
trunk/Tools/ChangeLog
trunk/Tools/WebKitTestRunner/Configurations/InjectedBundleCFLite.vsprops
trunk/Tools/WebKitTestRunner/Configurations/InjectedBundleCommon.vsprops
trunk/Tools/WebKitTestRunner/Configurations/InjectedBundleCoreFoundation.vsprops
trunk/Tools/WebKitTestRunner/InjectedBundle/InjectedBundlePage.cpp
trunk/Tools/WebKitTestRunner/WebKitTestRunner.xcodeproj/project.pbxproj




Diff

Modified: trunk/LayoutTests/ChangeLog (88624 => 88625)

--- trunk/LayoutTests/ChangeLog	2011-06-13 02:17:23 UTC (rev 88624)
+++ trunk/LayoutTests/ChangeLog	2011-06-13 03:05:02 UTC (rev 88625)
@@ -1,3 +1,12 @@
+2011-06-12  Dominic Cooney  domin...@chromium.org
+
+Reviewed by Hajime Morita.
+
+Add window.internals to WebKit2's WebKitTestRunner.
+https://bugs.webkit.org/show_bug.cgi?id=61073
+
+* platform/mac-wk2/Skipped: unskip fast/harness/internals-object.html
+
 2011-06-12  Sheriff Bot  webkit.review@gmail.com
 
 Unreviewed, rolling out r88616.


Modified: trunk/LayoutTests/platform/mac-wk2/Skipped (88624 => 88625)

--- trunk/LayoutTests/platform/mac-wk2/Skipped	2011-06-13 02:17:23 UTC (rev 88624)
+++ trunk/LayoutTests/platform/mac-wk2/Skipped	2011-06-13 03:05:02 UTC (rev 88625)
@@ -1522,9 +1522,6 @@
 # http://webkit.org/b/58990
 editing/undo/undo-iframe-location-change.html
 
-# https://bugs.webkit.org/show_bug.cgi?id=61073
-fast/harness/internals-object.html
-
 ### END OF (1) Classified failures with bug reports
 
 


Modified: trunk/Source/WebKit/win/ChangeLog (88624 => 88625)

--- trunk/Source/WebKit/win/ChangeLog	2011-06-13 02:17:23 UTC (rev 88624)
+++ trunk/Source/WebKit/win/ChangeLog	2011-06-13 03:05:02 UTC (rev 88625)
@@ -1,3 +1,12 @@
+2011-06-12  Dominic Cooney  domin...@chromium.org
+
+Reviewed by Hajime Morita.
+
+Add window.internals to WebKit2's WebKitTestRunner.
+https://bugs.webkit.org/show_bug.cgi?id=61073
+
+* WebKit.vcproj/WebKit.sln: InjectedBundle depends on WebCoreTestSupport
+
 2011-06-12  Adam Barth  aba...@webkit.org
 
 Reviewed by Alexey Proskuryakov.


Modified: trunk/Source/WebKit/win/WebKit.vcproj/WebKit.sln (88624 => 88625)

--- trunk/Source/WebKit/win/WebKit.vcproj/WebKit.sln	2011-06-13 02:17:23 UTC (rev 88624)
+++ trunk/Source/WebKit/win/WebKit.vcproj/WebKit.sln	2011-06-13 03:05:02 UTC (rev 88625)
@@ -122,6 +122,7 @@
 Project({8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}) = InjectedBundle, ..\..\..\..\Tools\WebKitTestRunner\win\InjectedBundle.vcproj, {CBC3391C-F060-4BF5-A66E-81404168816B}
 	ProjectSection(ProjectDependencies) = postProject
 		{4343BC0B-A2E0-4B48-8277-F33CFBFA83CD} = {4343BC0B-A2E0-4B48-8277-F33CFBFA83CD}
+		{83414B15-1C0D-490B-990E-03F4D49170E4} = {83414B15-1C0D-490B-990E-03F4D49170E4}
 	EndProjectSection
 EndProject
 Project({8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}) = InjectedBundleGenerated, ..\..\..\..\Tools\WebKitTestRunner\win\InjectedBundleGenerated.vcproj, {4343BC0B-A2E0-4B48-8277-F33CFBFA83CD}


Modified: trunk/Tools/ChangeLog (88624 => 88625)

--- trunk/Tools/ChangeLog	2011-06-13 02:17:23 UTC (rev 88624)
+++ trunk/Tools/ChangeLog	2011-06-13 03:05:02 UTC (rev 88625)
@@ -1,3 +1,19 @@
+2011-06-12  Dominic Cooney  domin...@chromium.org
+
+Reviewed by Hajime Morita.
+
+Add window.internals to WebKit2's WebKitTestRunner.
+https://bugs.webkit.org/show_bug.cgi?id=61073
+
+Test: 

[webkit-changes] [88627] trunk

2011-06-12 Thread commit-queue
Title: [88627] trunk








Revision 88627
Author commit-qu...@webkit.org
Date 2011-06-12 21:55:42 -0700 (Sun, 12 Jun 2011)


Log Message
2011-06-12  Hironori Bono  hb...@chromium.org

Reviewed by Hajime Morita.

Add null checks to HTMLTextAreaElement::removeSpellcheckRange().
https://bugs.webkit.org/show_bug.cgi?id=62526

This change adds null checks to the following function to prevent crashes
when calling removeSpellcheckRange() with null:
HTMLTextAreaElement::removeSpellcheckRange(),
HTMLInputElement::removeSpellcheckRange(), and
HTMLDivElement::removeSpellcheckRange().

* editing/spelling/spellcheck-api-crash-expected.txt: Added.
* editing/spelling/spellcheck-api-crash.html: Added.
2011-06-12  Hironori Bono  hb...@chromium.org

Reviewed by Hajime Morita.

Add null checks to HTMLTextAreaElement::removeSpellcheckRange().
https://bugs.webkit.org/show_bug.cgi?id=62526

This change adds null checks to the following function to prevent crashes
when calling removeSpellcheckRange() with null:
HTMLTextAreaElement::removeSpellcheckRange(),
HTMLInputElement::removeSpellcheckRange(), and
HTMLDivElement::removeSpellcheckRange().

Test: editing/spelling/spellcheck-api-crash.html

* html/HTMLDivElement.cpp:
(WebCore::HTMLDivElement::removeSpellcheckRange):
* html/HTMLInputElement.cpp:
(WebCore::HTMLInputElement::removeSpellcheckRange):
* html/HTMLTextAreaElement.cpp:
(WebCore::HTMLTextAreaElement::removeSpellcheckRange):

Modified Paths

trunk/LayoutTests/ChangeLog
trunk/Source/WebCore/ChangeLog
trunk/Source/WebCore/html/HTMLDivElement.cpp
trunk/Source/WebCore/html/HTMLInputElement.cpp
trunk/Source/WebCore/html/HTMLTextAreaElement.cpp


Added Paths

trunk/LayoutTests/editing/spelling/spellcheck-api-crash-expected.txt
trunk/LayoutTests/editing/spelling/spellcheck-api-crash.html




Diff

Modified: trunk/LayoutTests/ChangeLog (88626 => 88627)

--- trunk/LayoutTests/ChangeLog	2011-06-13 04:13:16 UTC (rev 88626)
+++ trunk/LayoutTests/ChangeLog	2011-06-13 04:55:42 UTC (rev 88627)
@@ -1,3 +1,19 @@
+2011-06-12  Hironori Bono  hb...@chromium.org
+
+Reviewed by Hajime Morita.
+
+Add null checks to HTMLTextAreaElement::removeSpellcheckRange().
+https://bugs.webkit.org/show_bug.cgi?id=62526
+
+This change adds null checks to the following function to prevent crashes
+when calling removeSpellcheckRange() with null:
+HTMLTextAreaElement::removeSpellcheckRange(),
+HTMLInputElement::removeSpellcheckRange(), and
+HTMLDivElement::removeSpellcheckRange().
+
+* editing/spelling/spellcheck-api-crash-expected.txt: Added.
+* editing/spelling/spellcheck-api-crash.html: Added.
+
 2011-06-12  Mahesh Kulkarni  mahesh.kulka...@nokia.com
 
 Reviewed by Antonio Gomes.


Added: trunk/LayoutTests/editing/spelling/spellcheck-api-crash-expected.txt (0 => 88627)

--- trunk/LayoutTests/editing/spelling/spellcheck-api-crash-expected.txt	(rev 0)
+++ trunk/LayoutTests/editing/spelling/spellcheck-api-crash-expected.txt	2011-06-13 04:55:42 UTC (rev 88627)
@@ -0,0 +1,7 @@
+This tests thats WebKit does not crash when we call removeSpellcheckRange() with a null parameter. To test manually, open this HTML file and check if the browser can open this file without a crash.
+
+
+
+wellcome
+
+


Added: trunk/LayoutTests/editing/spelling/spellcheck-api-crash.html (0 => 88627)

--- trunk/LayoutTests/editing/spelling/spellcheck-api-crash.html	(rev 0)
+++ trunk/LayoutTests/editing/spelling/spellcheck-api-crash.html	2011-06-13 04:55:42 UTC (rev 88627)
@@ -0,0 +1,27 @@
+html
+head
+title/title
+script language=_javascript_ type=text/_javascript_
+if (window.layoutTestController)
+layoutTestController.dumpAsText();
+
+function Test() {
+var node0 = document.getElementById('test0');
+if (node0.removeSpellcheckRange)
+node0.removeSpellcheckRange(null);
+var node1 = document.getElementById('test1');
+if (node1.removeSpellcheckRange)
+node1.removeSpellcheckRange(null);
+var node2 = document.getElementById('test2');
+if (node2.removeSpellcheckRange)
+node2.removeSpellcheckRange(null);
+}
+/script
+/head
+body _onload_=Test()
+pThis tests thats WebKit does not crash when we call removeSpellcheckRange() with a null parameter. To test manually, open this HTML file and check if the browser can open this file without a crash./p
+textarea id=test0 rows=10 cols=80wellcome/textareabr /
+input id=test1 type=text value=wellcome /br /
+div id=test2 contenteditable=truewellcome/divbr /
+/body
+/html


Modified: trunk/Source/WebCore/ChangeLog (88626 => 88627)

--- trunk/Source/WebCore/ChangeLog	2011-06-13 04:13:16 UTC (rev 88626)
+++ trunk/Source/WebCore/ChangeLog	2011-06-13 04:55:42 UTC (rev 88627)
@@
--- trunk/Source/WebCore/rendering/RenderText.cpp	2011-06-12 17:23:28 UTC (rev 88616)
+++ trunk/Source/WebCore/rendering/RenderText.cpp	2011-06-12 18:27:00 UTC (rev 88617)
@@ -1367,13 +1367,18 @@
 
 IntRect RenderText::clippedOverflowRectForRepaint(RenderBoxModelObject* repaintContainer)
 {
-bool repaintContainerSkipped;
-RenderObject* container = this-container(repaintContainer, repaintContainerSkipped);
-// The container may be an ancestor of repaintContainer, but we need to do a repaintContainer-relative repaint.
-if (repaintContainerSkipped)
+RenderObject* rendererToRepaint = containingBlock();
+
+// Do not cross self-painting layer boundaries.
+RenderObject* enclosingLayerRenderer = enclosingLayer()-renderer();
+if (enclosingLayerRenderer != rendererToRepaint  !rendererToRepaint-isDescendantOf(enclosingLayerRenderer))
+rendererToRepaint = enclosingLayerRenderer;
+
+// The renderer we chose to repaint may be an ancestor of repaintContainer, but we need to do a repaintContainer-relative repaint.
+if (repaintContainer  repaintContainer != rendererToRepaint  !rendererToRepaint-isDescendantOf(repaintContainer))
 return repaintContainer-clippedOverflowRectForRepaint(repaintContainer);
 
-return container-clippedOverflowRectForRepaint(repaintContainer);
+return rendererToRepaint-clippedOverflowRectForRepaint(repaintContainer);
 }
 
 IntRect RenderText::selectionRectForRepaint(RenderBoxModelObject* repaintContainer, bool clipToVisibleContent)






___
webkit-changes mailing list
webkit-changes@lists.webkit.org
http://lists.webkit.org/mailman/listinfo.cgi/webkit-changes


[webkit-changes] [88618] trunk/Source

2011-06-12 Thread abarth
Title: [88618] trunk/Source








Revision 88618
Author aba...@webkit.org
Date 2011-06-12 12:21:49 -0700 (Sun, 12 Jun 2011)


Log Message
2011-06-12  Adam Barth  aba...@webkit.org

Reviewed by Alexey Proskuryakov.

Remove trival forward-to-client member functions from FrameLoader
https://bugs.webkit.org/show_bug.cgi?id=62510

Update to call the FrameLoaderClient directly.  Also, remove cargo-cult
code that checks whether FrameLoader is null.

* webkit/webkitwebview.cpp:
(webkit_web_view_stop_loading):
(webkit_web_view_can_show_mime_type):
2011-06-12  Adam Barth  aba...@webkit.org

Reviewed by Alexey Proskuryakov.

Remove trival forward-to-client member functions from FrameLoader
https://bugs.webkit.org/show_bug.cgi?id=62510

* WebCoreSupport/WebFrameNetworkingContext.cpp:
(WebFrameNetworkingContext::blockedError):
2011-06-12  Adam Barth  aba...@webkit.org

Reviewed by Alexey Proskuryakov.

Remove trival forward-to-client member functions from FrameLoader
https://bugs.webkit.org/show_bug.cgi?id=62510

* WebCoreSupport/WebFrameNetworkingContext.mm:
(WebFrameNetworkingContext::blockedError):
2011-06-12  Adam Barth  aba...@webkit.org

Reviewed by Alexey Proskuryakov.

Remove trival forward-to-client member functions from FrameLoader
https://bugs.webkit.org/show_bug.cgi?id=62510

Originally, FrameLoader was supposed to abstract FrameLoaderClient, but
we lost that battle log ago.  Nowadays, it's easier if folks just call
into FrameLoaderClient directly.  Many of these functions have direct
callers already anyway.

* WebCore.exp.in:
* html/HTMLMediaElement.cpp:
(WebCore::HTMLMediaElement::createRenderer):
(WebCore::HTMLMediaElement::attach):
* loader/DocumentLoader.cpp:
(WebCore::DocumentLoader::setRequest):
(WebCore::DocumentLoader::setMainDocumentError):
(WebCore::DocumentLoader::setupForReplaceByMIMEType):
* loader/FrameLoader.cpp:
(WebCore::FrameLoader::didFirstLayout):
* loader/FrameLoader.h:
- cancelledError is slightly more delicate, so I'm going to move it in
  a separate patch.
* loader/MainResourceLoader.cpp:
(WebCore::MainResourceLoader::interruptForPolicyChangeError):
(WebCore::MainResourceLoader::stopLoadingForPolicyChange):
(WebCore::MainResourceLoader::continueAfterContentPolicy):
(WebCore::MainResourceLoader::handleEmptyLoad):
(WebCore::MainResourceLoader::loadNow):
* loader/MainResourceLoader.h:
* loader/NetscapePlugInStreamLoader.cpp:
(WebCore::NetscapePlugInStreamLoader::didReceiveResponse):
* loader/PingLoader.cpp:
(WebCore::PingLoader::PingLoader):
* loader/PolicyChecker.cpp:
(WebCore::PolicyChecker::continueAfterNavigationPolicy):
* loader/ResourceLoader.cpp:
(WebCore::ResourceLoader::blockedError):
(WebCore::ResourceLoader::cannotShowURLError):
(WebCore::ResourceLoader::shouldUseCredentialStorage):
(WebCore::ResourceLoader::canAuthenticateAgainstProtectionSpace):
* page/ContextMenuController.cpp:
(WebCore::ContextMenuController::populate):
2011-06-12  Adam Barth  aba...@webkit.org

Reviewed by Alexey Proskuryakov.

Remove trival forward-to-client member functions from FrameLoader
https://bugs.webkit.org/show_bug.cgi?id=62510

* WebProcess/WebCoreSupport/mac/WebFrameNetworkingContext.mm:
(WebKit::WebFrameNetworkingContext::blockedError):

Modified Paths

trunk/Source/WebCore/ChangeLog
trunk/Source/WebCore/WebCore.exp.in
trunk/Source/WebCore/html/HTMLMediaElement.cpp
trunk/Source/WebCore/loader/DocumentLoader.cpp
trunk/Source/WebCore/loader/FrameLoader.cpp
trunk/Source/WebCore/loader/FrameLoader.h
trunk/Source/WebCore/loader/MainResourceLoader.cpp
trunk/Source/WebCore/loader/MainResourceLoader.h
trunk/Source/WebCore/loader/NetscapePlugInStreamLoader.cpp
trunk/Source/WebCore/loader/PingLoader.cpp
trunk/Source/WebCore/loader/PolicyChecker.cpp
trunk/Source/WebCore/loader/ResourceLoader.cpp
trunk/Source/WebCore/page/ContextMenuController.cpp
trunk/Source/WebKit/gtk/ChangeLog
trunk/Source/WebKit/gtk/webkit/webkitwebview.cpp
trunk/Source/WebKit/mac/ChangeLog
trunk/Source/WebKit/mac/WebCoreSupport/WebFrameNetworkingContext.mm
trunk/Source/WebKit/win/ChangeLog
trunk/Source/WebKit/win/WebCoreSupport/WebFrameNetworkingContext.cpp
trunk/Source/WebKit2/ChangeLog
trunk/Source/WebKit2/WebProcess/WebCoreSupport/mac/WebFrameNetworkingContext.mm




Diff

Modified: trunk/Source/WebCore/ChangeLog (88617 => 88618)
